@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.2.2 $
+### $Release: 0.3.0 $
 ### $Copyright: copyright(c) 2010 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -9,7 +9,7 @@
 ##
 ## cookbook for pykook -- you must install pykook at first.
 ## pykook is a build tool like Rake. you can define your task in Python.
-## http://pypi.python.org/pypi/Kook/0.0.1
+## http://pypi.python.org/pypi/Kook/
 ## http://www.kuwata-lab.com/kook/pykook-users-guide.html
 ##
 
@@ -19,28 +19,36 @@ import os, re
 from glob import glob
 from kook.utils import read_file, write_file
 
-release = prop('release', '0.2.2')
-package = prop('package', 'Oktest')
+release   = prop('release', '0.3.0')
+package   = prop('package', 'Oktest')
 copyright = prop('copyright', "copyright(c) 2010 kuwata-lab.com all rights reserved")
+license   = "MIT License"
+#kook_default_product = 'test'
 
-license         = "MIT License"
-#python_basepath = "/Library/Frameworks/Python.framework/Versions/2.4"
-#site_packages_path = "%s/lib/python2.4/site-packages" % python_basepath
-python_basepath = "/usr/local/lib/python2.5"
-site_packages_path = "%s/site-packages" % python_basepath
-script_file     = "pytenjin"
-library_files   = [ "tenjin.py" ]
-
-kook_default_product = 'test'
+python = prop('python', 'python')
 
 
 @recipe
 def task_test(c):
-    system("python test/oktest_test.py")
+    system(c%"$(python) test/oktest_test.py")
 
 
 @recipe
-def task_package(c):
+def task_edit(c):
+    def replacer(s):
+        s = re.sub(r'\$Release:[^%]*?\$',    '$Release: %s $'   % release,   s)
+        s = re.sub(r'\$Copyright:[^%]*?\$',  '$Copyright: %s $' % copyright, s)
+        s = re.sub(r'\$License:[^%]*?\$',    '$License: %s $'   % license,   s)
+        return s
+    filenames = read_file('MANIFEST').splitlines()
+    filenames.remove('Kookbook.py')
+    filenames.append('README.wiki')
+    edit(filenames, by=replacer)
+
+
+@recipe
+@spices('-a: create egg files for 2.4-2.7')
+def task_package(c, *args, **kwargs):
     """create package"""
     ## remove files
     pattern = c%"dist/$(package)-$(release)*"
@@ -48,17 +56,20 @@ def task_package(c):
         rm_rf(pattern)
     ## edit files
     repl = (
-        (r'\$Release\$', release),
-        (r'\$Release: 0.2.2 $', '$Release: 0.2.2 $' % release),
+        (r'\$Release\$',   release),
         (r'\$Copyright\$', copyright),
-        (r'\$Package\$', package),
-        (r'\$License\$', license),
+        (r'\$License\$',   license),
+        (r'\$Package\$',   package),
+        (r'\$Release:[^%]*?\$',   '$Release: %s $'   % release),
+        (r'\$Copyright:[^%]*?\$', '$Copyright: %s $' % copyright),
+        (r'\$License:[^%]*?\$',   '$License: %s $'   % license),
+        (r'X\.X\.X',   release),
     )
     cp('setup.py.txt', 'setup.py')
     edit('setup.py', by=repl)
     ## setup
-    system('python setup.py sdist')
-    #system('python setup.py sdist --keep-temp')
+    system(c%'$(python) setup.py sdist')
+    #system(c%'$(python) setup.py sdist --keep-temp')
     with chdir('dist') as d:
         #pkgs = kook.util.glob2(c%"$(package)-$(release).tar.gz");
         #pkg = pkgs[0]
@@ -70,43 +81,34 @@ def task_package(c):
         #echo("*** debug: pkg=%s, dir=%s" % (pkg, dir))
         edit(c%"$(dir)/**/*", by=repl)
         #with chdir(dir):
-        #    system("python setup.py egg_info --egg-base .")
+        #    system(c%"$(python) setup.py egg_info --egg-base .")
         #    rm("*.pyc")
         mv(pkg, c%"$(pkg).bkup")
         #tar_czf(c%"$(dir).tar.gz", dir)
         system(c%"tar -cf $(dir).tar $(dir)")
         system(c%"gzip -f9 $(dir).tar")
         ## create *.egg file
+        opt_a = kwargs.get('a')
         with chdir(dir):
-            system("python setup.py bdist_egg")
-            mv("dist/*.egg", "..")
-            rm_rf("build", "dist")
-
-
-@recipe
-def task_uninstall(c):
-    #script_file    = "$python_basepath/bin/" + script_file;
-    #library_files  = [ os.path.join(site_packages_path, item) for item in library_files ]
-    #compiled_files = [ item + '.c' for item in library_files ]
-    script_file = "/usr/local/bin/pytenjin"
-    dir = site_packages_dir
-    library_files = "$dir/$(package)*"
-    rm(script_file, library_files)
-    filename = "$dir/easy-install.pth"
-    if os.path.exists(filename):
-        s = read_file(filename)
-        pattern = r'/^\.\/$(package)-.*\n/m'
-        if re.match(pattern, s):
-            s = re.sub(pattern, s)
-        write_file(filename, s)
-        repl = ((pattern, ''), )
-        edit(filename, by=repl)
+            if opt_a:
+                pythons = [
+                    '/opt/local/bin/python2.7',
+                    '/opt/local/bin/python2.6',
+                    '/opt/local/bin/python2.5',
+                    '/opt/local/bin/python2.4',
+                ]
+            else:
+                pythons = [ python ]
+            for py in pythons:
+                system(c%'$(py) setup.py bdist_egg')
+                mv("dist/*.egg", "..")
+                rm_rf("build", "dist")
 
 
 @recipe
 def task_clean(c):
-    pass
-    from glob import glob
+    rm_rf('**/*.pyc', 'dist', c%'$(package).zip')
+
 
 @recipe
 @product('website/index.html')
@@ -118,8 +120,8 @@ def file_website_index_html(c):
     opts = '--stylesheet-path=style.css --link-stylesheet --strip-class=field --strip-class=field-name --strip-class=field-body'
     system(c%'rst2html.py $(opts) $(ingred) > $(product)')
     def f(s):
-        s = s.replace('$Release: 0.2.2 $', '$Release: 0.2.2 $' % release)
-        s = s.replace('0.2.2', release)
+        s = s.replace('$Release:[^%]*?$', '$Release: %s $' % release)
+        s = s.replace('$'+'Release'+'$', release)
         s = s.replace('README', 'Oktest - a new style testing library -')
         #s = re.sub(r'^<h(\d)>(.*?)</h\d>', r, s)
         pat = re.compile(r'^<h(\d)>(.*?)</h\d>', re.M)
