@@ -1,5 +1,5 @@
 ###
-### $Release: 0.2.2 $
+### $Release: 0.3.0 $
 ### $Copyright: copyright(c) 2010 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -25,17 +25,20 @@ os.environ['OKTEST_REPORTER'] = 'OldStyleReporter'
 import oktest
 
 echo = sys.stdout.write
+python_command = os.environ.get('PYTHON', 'python')
 
-def do_test_with(desc, script, expected):
+def do_test_with(desc, script, expected,  _pat=re.compile(r'0\.00[01]s')):
     filename = '_test_.py'
     try:
         echo("- %s..." % desc)
         open(filename, 'w').write(script)
-        output = os.popen('python '+filename).read()
+        output = os.popen(python_command + ' ' + filename).read()
         if isinstance(output, str):
             output = re.sub(r' at 0x[0-9a-f]{6}', '', output)
         if output == expected:
             echo("done.\n")
+        elif _pat.sub('', output) == _pat.sub('', expected):
+            echo("done.\n")
         else:
             echo("FAILED.\n")
             if (isinstance(output, str) and isinstance(expected, str)):
@@ -95,6 +98,7 @@ expected = r"""
 """[1:]
 do_test_with(desc, script, expected)
 
+
 ###
 desc = "before_all/before_each/after_each/after_all"
 script = r"""
@@ -106,34 +110,87 @@ class FooTest(object):
     def after_all(cls):
         print('after_all() called.')
     after_all  = classmethod(after_all)
-    def before_each(self):
-        print('before_each() called.')
-    def after_each(self):
-        print('after_each() called.')
+    def before(self):
+        print('before() called.')
+    def after(self):
+        print('after() called.')
     #
     def test_1(self):
         print('test_1() called.')
+        ok (1+1) == 2
     def test_2(self):
         print('test_2() called.')
+        ok (1+1) == 3
+    def test_3(self):
+        print('test_3() called.')
+        int('abc')
 run('FooTest')
 """[1:]
 expected = r"""
 before_all() called.
-* FooTest.test_1 ... before_each() called.
+* FooTest.test_1 ... before() called.
 test_1() called.
 [ok]
-after_each() called.
-* FooTest.test_2 ... before_each() called.
+after() called.
+* FooTest.test_2 ... before() called.
 test_2() called.
-[ok]
-after_each() called.
+[NG] 2 == 3 : failed.
+   _test_.py:19: ok (1+1) == 3
+after() called.
+* FooTest.test_3 ... before() called.
+test_3() called.
+[ERROR] ValueError: invalid literal for int() with base 10: 'abc'
+  - _test_.py:22:  int('abc')
+after() called.
 after_all() called.
 """[1:]
 do_test_with(desc, script, expected)
 
+###
+desc = "setUp()/tearDown()"
+script = r"""
+from oktest import *
+class FooTest(object):
+    def setUp(self):
+        print('setUp() called.')
+    def tearDown(self):
+        print('tearDown() called.')
+    #
+    def test_1(self):
+        print('test_1() called.')
+        ok (1+1) == 2
+    def test_2(self):
+        print('test_2() called.')
+        ok (1+1) == 3
+    def test_3(self):
+        print('test_3() called.')
+        int('abc')
+run('FooTest')
+"""[1:]
+expected = r"""
+* FooTest.test_1 ... setUp() called.
+test_1() called.
+[ok]
+tearDown() called.
+* FooTest.test_2 ... setUp() called.
+test_2() called.
+[NG] 2 == 3 : failed.
+   _test_.py:13: ok (1+1) == 3
+tearDown() called.
+* FooTest.test_3 ... setUp() called.
+test_3() called.
+[ERROR] ValueError: invalid literal for int() with base 10: 'abc'
+  - _test_.py:16:  int('abc')
+tearDown() called.
+"""[1:]
+do_test_with(desc, script, expected)
+
+
 ###
 desc = "op '=='"
 script = r"""
+import oktest
+oktest.DIFF = False
 from oktest import *
 class FooTest(object):
     def test_inteq(self):
@@ -151,9 +208,9 @@ expected = r"""
 * FooTest.test_inteq ... [ok]
 * FooTest.test_streq ... [ok]
 * BarTest.test_inteq ... [NG] 16 == 15 : failed.
-   _test_.py:9: ok (4*4) == 15
+   _test_.py:11: ok (4*4) == 15
 * BarTest.test_streq ... [NG] 'FOO' == 'foo' : failed.
-   _test_.py:11: ok ("foo".upper()) == 'foo'
+   _test_.py:13: ok ("foo".upper()) == 'foo'
 """[1:]
 do_test_with(desc, script, expected)
 
@@ -624,3 +681,158 @@ run(FooTest)
 """
 expected = "* FooTest.test_chdir2 ... [ok]\n"
 do_test_with(desc, script, expected)
+
+
+### diff (oktest.DIFF = True)
+desc = "diff (oktest.DIFF = True)"
+script = r"""
+from oktest import *
+import oktest
+oktest.DIFF = True
+class FooTest(object):
+    def test1(self):
+       ok ('foo') == 'foo1'
+    def test2(self):
+       ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+run(FooTest)
+"""[1:]
+expected = r"""
+* FooTest.test1 ... [NG] 'foo' == 'foo1' : failed.
+   _test_.py:6: ok ('foo') == 'foo1'
+--- expected 
++++ actual 
+@@ -1,1 +1,1 @@
+-foo1
++foo
+* FooTest.test2 ... [NG] 'AAA\nBBB\nCCC\n' == 'AAA\n888\nCCC' : failed.
+   _test_.py:8: ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+--- expected 
++++ actual 
+@@ -1,3 +1,3 @@
+ AAA
+-888
+-CCC
+\ No newline at end of string
++BBB
++CCC
+"""[1:]
+do_test_with(desc, script, expected)
+
+### diff (oktest.DIFF == 'repr')
+desc = "diff (oktest.DIFF == 'repr')"
+script = r"""
+from oktest import *
+import oktest
+oktest.DIFF = repr
+class FooTest(object):
+    def test1(self):
+        ok ('foo') == 'foo1'
+    def test2(self):
+        ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+run(FooTest)
+"""[1:]
+expected = r"""
+* FooTest.test1 ... [NG] 'foo' == 'foo1' : failed.
+   _test_.py:6: ok ('foo') == 'foo1'
+--- expected 
++++ actual 
+@@ -1,1 +1,1 @@
+-'foo1'
++'foo'
+* FooTest.test2 ... [NG] 'AAA\nBBB\nCCC\n' == 'AAA\n888\nCCC' : failed.
+   _test_.py:8: ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+--- expected 
++++ actual 
+@@ -1,3 +1,3 @@
+ 'AAA\n'
+-'888\n'
+-'CCC'
++'BBB\n'
++'CCC\n'
+"""[1:]
+do_test_with(desc, script, expected)
+
+### diff (oktest.DIFF == False)
+desc = "diff (oktest.DIFF == False)"
+script = r"""
+from oktest import *
+import oktest
+oktest.DIFF = False
+class FooTest(object):
+    def test1(self):
+       ok ('foo') == 'foo1'
+    def test2(self):
+       ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+run(FooTest)
+"""[1:]
+expected = r"""
+* FooTest.test1 ... [NG] 'foo' == 'foo1' : failed.
+   _test_.py:6: ok ('foo') == 'foo1'
+* FooTest.test2 ... [NG] 'AAA\nBBB\nCCC\n' == 'AAA\n888\nCCC' : failed.
+   _test_.py:8: ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+"""[1:]
+do_test_with(desc, script, expected)
+
+
+## unittest compatibility
+desc = "unittest compatibility"
+script = r"""
+from oktest import *
+import sys
+sys.stderr = sys.stdout
+import unittest
+class FooTest(unittest.TestCase):
+  def test1(self):
+    ok (1+1) == 2
+  def test2(self):
+    ok (1+1) == 3
+unittest.main()
+"""[1:]
+expected = r"""
+.F
+======================================================================
+FAIL: test2 (__main__.FooTest)
+----------------------------------------------------------------------
+Traceback (most recent call last):
+  File "_test_.py", line 9, in test2
+    ok (1+1) == 3
+AssertionError: 2 == 3 : failed.
+
+----------------------------------------------------------------------
+Ran 2 tests in 0.000s
+
+FAILED (failures=1)
+"""[1:]
+do_test_with(desc, script, expected)
+
+
+## simple reporter
+desc = "simple reporter"
+script = r"""
+from oktest import *
+import sys
+sys.stderr = sys.stdout
+import unittest
+class FooTest(object):
+  def test_success(self):
+    ok (1+1) == 2
+  def test_failed(self):
+    ok (1+1) == 3
+  def test_error(self):
+    ok (int('aaa')) == 0
+run(FooTest)
+"""[1:]
+expected = r"""
+### FooTest
+.fE
+Failed: FooTest#test_failed()
+  2 == 3 : failed.
+  File "_test_.py", line 9
+    ok (1+1) == 3
+ERROR: FooTest#test_error()
+  ValueError: invalid literal for int() with base 10: 'aaa'
+  File "_test_.py", line 11, in test_error
+    ok (int('aaa')) == 0
+"""[1:]
+os.environ['OKTEST_REPORTER'] = 'SimpleReporter'
+do_test_with(desc, script, expected)
